TestEffect class abstract

Implementers
Available extensions

Constructors

TestEffect()

Properties

effects → Subject<Effect>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

input<I extends Object?>(Function method, I input) Future<I>

Available on TestEffect, provided by the X extension

io<I extends Object?, O extends Object?>(Function method, {required O output, required I input, Duration duration = const Duration(seconds: 0)}) Future<I>

Available on TestEffect, provided by the X extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output<I extends Object?>(Function method, I output) Future<void>

Available on TestEffect, provided by the X extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited