TestStateStream<State> class

Inheritance

Constructors

TestStateStream({required State state, Subject<Effect>? effects})

Properties

effects → Subject<Effect>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ State
getter/setter pairinherited-getteroverride-setter
stream Stream<State>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revive(Reviver<State> reviver) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited