X extension

on

Properties

name String

Available on Function, provided by the X extension

Very hacky way to get the name of a method, which doesn't work for web. Please let me know if you know a better way without reflection.
no setter