TestEffect class abstract
- Implementers
- Available extensions
Constructors
Properties
Methods
-
input<
I extends Object?> (Function method, I input) → Future< I> -
Available on TestEffect, provided by the X extension
-
io<
I extends Object?, O extends Object?> (Function method, {required O output, required I input, Duration duration = const Duration(seconds: 0)}) → Future< I> -
Available on TestEffect, provided by the X extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
output<
I extends Object?> (Function method, I output) → Future< void> -
Available on TestEffect, provided by the X extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited