menu
revive package
documentation
utils/function.dart
X extension
X extension
dark_mode
light_mode
X
extension
on
Function
Properties
name
→
String
Available on
Function
, provided by the
X
extension
Very hacky way to get the name of a method, which doesn't work for web. Please let me know if you know a better way without reflection.
no setter
revive package
documentation
utils/function
X extension
function library